@@ -104,6 +104,8 @@ class SwidgetDevice:
         for assembly in self.assemblies:
             _LOGGER.error(f"Processing assembly: {assembly}")
             for id, component in self.assemblies[assembly].components.items():
+                if id == "0":
+                    continue
                 _LOGGER.error(f"id: {id} comp: {component}")
                 try:
                     component.functions.update(state[assembly]["components"][id])
